==> blesta-5.10.2.zip: blesta/language/de_de/app_controller.php <==
<?php
/**
 * App Controller
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AppController.sreader.navigation'] = 'Navigation umschalten';
$lang['AppController.sreader.dropdown'] = 'Dropdown umschalten';
$lang['AppController.graphs.label.total'] = 'Insgesamt';
$lang['AppController.graphs.control_label.grouped'] = 'Gruppiert';
$lang['AppController.graphs.control_label.expanded'] = 'Erweitert';
$lang['AppController.graphs.control_label.stream'] = 'Stream';
$lang['AppController.graphs.control_label.stacked'] = 'Gestapelt';
$lang['AppController.dates.monthabbr_dec'] = 'Dez.';
$lang['AppController.dates.monthabbr_nov'] = 'Nov.';
$lang['AppController.dates.monthabbr_oct'] = 'Okt.';
$lang['AppController.dates.monthabbr_sep'] = 'Sep';
$lang['AppController.dates.monthabbr_aug'] = 'Aug';
$lang['AppController.dates.monthabbr_jul'] = 'Jul';
$lang['AppController.dates.monthabbr_jun'] = 'Jun';
$lang['AppController.dates.monthabbr_may'] = 'Mai';
$lang['AppController.dates.monthabbr_apr'] = 'Apr.';
$lang['AppController.dates.monthabbr_mar'] = 'März';
$lang['AppController.dates.monthabbr_feb'] = 'Februar';
$lang['AppController.dates.monthabbr_jan'] = 'Jan';
$lang['AppController.dates.month_dec'] = 'Dezember';
$lang['AppController.dates.month_nov'] = 'November';
$lang['AppController.dates.month_oct'] = 'Oktober';
$lang['AppController.dates.month_sep'] = 'September';
$lang['AppController.dates.month_aug'] = 'August';
$lang['AppController.dates.month_jul'] = 'Juli';
$lang['AppController.dates.month_jun'] = 'Juni';
$lang['AppController.dates.month_may'] = 'Mai';
$lang['AppController.dates.month_apr'] = 'April';
$lang['AppController.dates.month_mar'] = 'März';
$lang['AppController.dates.month_feb'] = 'Februar';
$lang['AppController.dates.month_jan'] = 'Januar';
$lang['AppController.dates.dayabbr_sat'] = 'Sat';
$lang['AppController.dates.dayabbr_fri'] = 'Fr';
$lang['AppController.dates.dayabbr_thur'] = 'Thu';
$lang['AppController.dates.dayabbr_wed'] = 'Mi';
$lang['AppController.dates.dayabbr_tue'] = 'Di';
$lang['AppController.dates.dayabbr_mon'] = 'Mo';
$lang['AppController.dates.dayabbr_sun'] = 'Sonne';
$lang['AppController.dates.day_sat'] = 'Samstag';
$lang['AppController.dates.day_fri'] = 'Freitag';
$lang['AppController.dates.day_thu'] = 'Donnerstag';
$lang['AppController.dates.day_wed'] = 'Mittwoch';
$lang['AppController.dates.day_tue'] = 'Dienstag';
$lang['AppController.dates.day_mon'] = 'Montag';
$lang['AppController.dates.day_sun'] = 'Sonntag';
$lang['AppController.client_structure.text_managers'] = 'Manager';
$lang['AppController.client_structure.text_contacts'] = 'Kontakte';
$lang['AppController.client_structure.text_accounts'] = 'Zahlungskonten';
$lang['AppController.client_structure.text_emails'] = 'E-Mail-Verlauf';
$lang['AppController.client_structure.text_update_account'] = 'Konto verwalten';
$lang['AppController.client_structure.text_login'] = 'Einloggen';
$lang['AppController.client_structure.text_logout'] = 'Abmelden';
$lang['AppController.client_structure.text_return_to_portal'] = 'Zurück zum Portal';
$lang['AppController.client_structure.default_title'] = 'Mein Konto';
$lang['AppController.client_structure.staff_as_client_note'] = 'Zurück zum Personalportal';
$lang['AppController.structure.text_search_placeholder'] = '%1$s...';
$lang['AppController.structure.text_maintenance'] = 'Der Wartungsmodus ist derzeit aktiviert und Clients können sich nicht anmelden. Klicken Sie hier, um zu ändern.';
$lang['AppController.structure.text_logout'] = 'Abmelden';
$lang['AppController.structure.text_settings'] = 'Einstellungen';
$lang['AppController.structure.text_myinfo'] = 'Meine Infos';
$lang['AppController.message.close'] = '×';
$lang['AppController.banners.text_switch_back'] = 'Zurück zu meinem Konto wechseln';
$lang['AppController.banners.client_manager'] = 'Sie verwalten gerade ein Konto, das Sie zur Verwaltung eingeladen hat.';
$lang['AppController.tooltip.text'] = '?';
$lang['AppController.modal.text_confirm'] = 'Bitte bestätigen Sie';
$lang['AppController.modal.text_close'] = 'Schließen Sie';
$lang['AppController.select.please'] = '-- Bitte wählen Sie --';
$lang['AppController.!success.license_key_updated'] = 'Ihr Lizenzschlüssel wurde erfolgreich aktualisiert. Bitte melden Sie sich an.';
$lang['AppController.!success.license_updated'] = 'Ihre Lizenz wurde erfolgreich revalidiert. Bitte loggen Sie sich ein.';
$lang['AppController.!error.invalid_csrf'] = 'Das Formular-Token ist ungültig.';
$lang['AppController.!error.unauthorized_access'] = 'Sie sind nicht berechtigt, auf diese Ressource zuzugreifen';
$lang['AppController.lang.dir'] = 'ltr';
$lang['AppController.dropzone.text'] = 'Dateien zum Hochladen hier ablegen oder zum Auswählen von Dateien anklicken';

==> blesta-5.11.4.zip: blesta/language/de_de/app_controller.php <==
<?php
/**
 * App Controller
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AppController.sreader.navigation'] = 'Navigation umschalten';
$lang['AppController.sreader.dropdown'] = 'Dropdown umschalten';
$lang['AppController.graphs.label.total'] = 'Insgesamt';
$lang['AppController.graphs.control_label.grouped'] = 'Gruppiert';
$lang['AppController.graphs.control_label.expanded'] = 'Erweitert';
$lang['AppController.graphs.control_label.stream'] = 'Stream';
$lang['AppController.graphs.control_label.stacked'] = 'Gestapelt';
$lang['AppController.dates.monthabbr_dec'] = 'Dez.';
$lang['AppController.dates.monthabbr_nov'] = 'Nov.';
$lang['AppController.dates.monthabbr_oct'] = 'Okt.';
$lang['AppController.dates.monthabbr_sep'] = 'Sep';
$lang['AppController.dates.monthabbr_aug'] = 'Aug';
$lang['AppController.dates.monthabbr_jul'] = 'Jul';
$lang['AppController.dates.monthabbr_jun'] = 'Jun';
$lang['AppController.dates.monthabbr_may'] = 'Mai';
$lang['AppController.dates.monthabbr_apr'] = 'Apr.';
$lang['AppController.dates.monthabbr_mar'] = 'März';
$lang['AppController.dates.monthabbr_feb'] = 'Februar';
$lang['AppController.dates.monthabbr_jan'] = 'Jan';
$lang['AppController.dates.month_dec'] = 'Dezember';
$lang['AppController.dates.month_nov'] = 'November';
$lang['AppController.dates.month_oct'] = 'Oktober';
$lang['AppController.dates.month_sep'] = 'September';
$lang['AppController.dates.month_aug'] = 'August';
$lang['AppController.dates.month_jul'] = 'Juli';
$lang['AppController.dates.month_jun'] = 'Juni';
$lang['AppController.dates.month_may'] = 'Mai';
$lang['AppController.dates.month_apr'] = 'April';
$lang['AppController.dates.month_mar'] = 'März';
$lang['AppController.dates.month_feb'] = 'Februar';
$lang['AppController.dates.month_jan'] = 'Januar';
$lang['AppController.dates.dayabbr_sat'] = 'Sat';
$lang['AppController.dates.dayabbr_fri'] = 'Fr';
$lang['AppController.dates.dayabbr_thur'] = 'Thu';
$lang['AppController.dates.dayabbr_wed'] = 'Mi';
$lang['AppController.dates.dayabbr_tue'] = 'Di';
$lang['AppController.dates.dayabbr_mon'] = 'Mo';
$lang['AppController.dates.dayabbr_sun'] = 'Sonne';
$lang['AppController.dates.day_sat'] = 'Samstag';
$lang['AppController.dates.day_fri'] = 'Freitag';
$lang['AppController.dates.day_thu'] = 'Donnerstag';
$lang['AppController.dates.day_wed'] = 'Mittwoch';
$lang['AppController.dates.day_tue'] = 'Dienstag';
$lang['AppController.dates.day_mon'] = 'Montag';
$lang['AppController.dates.day_sun'] = 'Sonntag';
$lang['AppController.client_structure.text_managers'] = 'Manager';
$lang['AppController.client_structure.text_contacts'] = 'Kontakte';
$lang['AppController.client_structure.text_accounts'] = 'Zahlungskonten';
$lang['AppController.client_structure.text_emails'] = 'E-Mail-Verlauf';
$lang['AppController.client_structure.text_update_account'] = 'Konto verwalten';
$lang['AppController.client_structure.text_login'] = 'Einloggen';
$lang['AppController.client_structure.text_logout'] = 'Abmelden';
$lang['AppController.client_structure.text_return_to_portal'] = 'Zurück zum Portal';
$lang['AppController.client_structure.default_title'] = 'Mein Konto';
$lang['AppController.client_structure.staff_as_client_note'] = 'Zurück zum Personalportal';
$lang['AppController.structure.text_search_placeholder'] = '%1$s...';
$lang['AppController.structure.text_maintenance'] = 'Der Wartungsmodus ist derzeit aktiviert und Clients können sich nicht anmelden. Klicken Sie hier, um zu ändern.';
$lang['AppController.structure.text_logout'] = 'Abmelden';
$lang['AppController.structure.text_settings'] = 'Einstellungen';
$lang['AppController.structure.text_myinfo'] = 'Meine Infos';
$lang['AppController.message.close'] = '×';
$lang['AppController.banners.text_switch_back'] = 'Zurück zu meinem Konto wechseln';
$lang['AppController.banners.client_manager'] = 'Sie verwalten gerade ein Konto, das Sie zur Verwaltung eingeladen hat.';
$lang['AppController.tooltip.text'] = '?';
$lang['AppController.modal.text_confirm'] = 'Bitte bestätigen Sie';
$lang['AppController.modal.text_close'] = 'Schließen Sie';
$lang['AppController.select.please'] = '-- Bitte wählen Sie --';
$lang['AppController.!success.license_key_updated'] = 'Ihr Lizenzschlüssel wurde erfolgreich aktualisiert. Bitte melden Sie sich an.';
$lang['AppController.!success.license_updated'] = 'Ihre Lizenz wurde erfolgreich revalidiert. Bitte loggen Sie sich ein.';
$lang['AppController.!error.invalid_csrf'] = 'Das Formular-Token ist ungültig.';
$lang['AppController.!error.unauthorized_access'] = 'Sie sind nicht berechtigt, auf diese Ressource zuzugreifen';
$lang['AppController.lang.dir'] = 'ltr';
$lang['AppController.dropzone.text'] = 'Dateien zum Hochladen hier ablegen oder zum Auswählen von Dateien anklicken';
$lang['AppController.!error.client_unauthorized_access'] = 'Sie haben keine Zugriffsberechtigung für diese Ressource. Bitte wenden Sie sich an den Inhaber des Hauptkontos, um den Zugriff zu beantragen.';
